summaryrefslogtreecommitdiff
path: root/src/nautilus-location-bar.c
diff options
context:
space:
mode:
authorMartin Wehner <martin.wehner@gmail.com>2005-03-25 14:02:02 +0000
committerMartin Wehner <mwehner@src.gnome.org>2005-03-25 14:02:02 +0000
commit8dfdc1cd4ba873369cc2ee8f27b85533f1ba49e2 (patch)
treed84e9804a14373f0ae3f02c0a1917cb6cf7ce950 /src/nautilus-location-bar.c
parent75803edc7d913042667a8d70613050acab3cf7ee (diff)
downloadnautilus-8dfdc1cd4ba873369cc2ee8f27b85533f1ba49e2.tar.gz
Replace eel_make_uri_from_input with the gnome-vfs equivalent. Closes bug
2005-03-25 Martin Wehner <martin.wehner@gmail.com> * src/nautilus-connect-server-dialog.c: (connect_to_server): * src/nautilus-location-bar.c: (nautilus_location_bar_get_location), (nautilus_location_bar_update_label): * src/nautilus-location-dialog.c: (open_current_location): Replace eel_make_uri_from_input with the gnome-vfs equivalent. Closes bug #165743. Patch from Christian Kellner <gicmo@gnome.org>
Diffstat (limited to 'src/nautilus-location-bar.c')
-rw-r--r--src/nautilus-location-bar.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/nautilus-location-bar.c b/src/nautilus-location-bar.c
index fb0c422f9..0416e21c4 100644
--- a/src/nautilus-location-bar.c
+++ b/src/nautilus-location-bar.c
@@ -484,7 +484,7 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
* @bar: A NautilusLocationBar.
*
* returns a newly allocated "string" containing the mangled
* (by eel_make_uri_from_input) text that the user typed in...maybe a URI
* but not guaranteed.
*
**/
@@ -497,7 +497,7 @@ nautilus_location_bar_get_location (NautilusNavigationBar *navigation_bar)
bar = NAUTILUS_LOCATION_BAR (navigation_bar);
user_location = gtk_editable_get_chars (GTK_EDITABLE (bar->details->entry), 0, -1);
- best_uri = eel_make_uri_from_input (user_location);
+ best_uri = gnome_vfs_make_uri_from_input (user_location);
g_free (user_location);
return best_uri;
}
@@ -515,7 +515,7 @@ nautilus_location_bar_update_label (NautilusLocationBar *bar)
char *current_location;
current_text = gtk_entry_get_text (GTK_ENTRY (bar->details->entry));
- current_location = eel_make_uri_from_input (current_text);
+ current_location = gnome_vfs_make_uri_from_input (current_text);
if (gnome_vfs_uris_match (bar->details->last_location, current_location)) {
gtk_label_set_text (GTK_LABEL (bar->details->label), LOCATION_LABEL);
@@ -484,7 +484,7 @@ nautilus_location_bar_set_location (NautilusNavigationBar *navigation_bar,
*
* returns a newly allocated "string" containing the mangled
- * (by eel_make_uri_from_input) text that the user typed in...maybe a URI
+ * (by gnome_vfs_make_uri_from_input) text that the user typed in...maybe a URI
* but not guaranteed.
*